<?php
/**
 * @file
 * Subscription entity metadata integration.
 */

/**
 * Extend the defaults.
 */
class SubsMetadataController extends EntityDefaultMetadataController {

  public function entityPropertyInfo() {
    $info = parent::entityPropertyInfo();
    $properties = &$info[$this->type]['properties'];

    // Complement type property.
    $properties['type'] = array(
      'type' => 'subs_type',
      'setter permission' => 'administer subs',
      'required' => TRUE,
      'description' => t('The subscription type.'),
    ) + $properties['type'];

    // Replace uid property with an entity relationship.
    $properties['uid'] = array(
      'label' => t('User'),
      'type' => 'user',
      'description' => t('The unique ID of the user who subscribed.'),
      'required' => TRUE,
      'schema field' => 'uid',
    );

    // Complement created property info.
    $properties['created']['type'] = 'date';
    $properties['created']['description'] = t('The date the subscription was posted.');
    $properties['created']['setter permission'] = 'administer subs';

    // Complement changed property info.
    $properties['changed']['type'] = 'date';
    $properties['changed']['description'] = t('The date the subscription was most recently updated.');

    // Complement date_start property info.
    $properties['date_start']['label'] = t('Start Date');
    $properties['date_start']['type'] = 'date';
    $properties['date_start']['description'] = t('The date the subscription started.');

    // Complement date_end property info.
    $properties['date_end']['label'] = t('End Date');
    $properties['date_end']['type'] = 'date';
    $properties['date_end']['description'] = t('The date the subscription ends.');

    // Complement status property info.
    $properties['status']['description'] = t("The subscription's status.");
    $properties['status']['options list'] = 'subs_status_options_list';
    $properties['status']['access callback'] = 'administer subs';

    return $info;
  }
}